# install
From Pypi:

`py -m pip install polyglots`

From GitHub:

`py -m pip install git+https://github.com/donno2048/polyglots`

To use it just run:
```py
polyglots
```

If you run this on a zip and a pdf for example, you will end-up with a file you can open as a pdf or as a zip and is actually containing the content of the origin files

[Available formats:](https://github.com/donno2048/polyglots/blob/main/polyglots/__main__.py#L542)

arj, ar, bmp, bpg, cpio, cab, ebml, flac, flv, gif, icc, ico, ilda, java, jp2, jpg, lnk, id3v2, nes, ogg, pcap, pcapng, pe_hdr, pe_sec, png, psd, riff, svg, tiff, wasm, xz, 7z, mp4, pdf, gzip, bzip2, postscript, zip, rar, rtf, dcm, tar, pdfc, iso, id3v1
